@@ -79,12 +79,12 @@ indicate_indicator_class_init (IndicateIndicatorClass * class)
 	gobj->finalize = indicate_indicator_finalize;
 
 	/** 
-		IndicateIndicator::display:
-		@arg0: The #IndicateIndicator object
-
-		Emitted when the user has clicked on this indicator.  In the
-		messaging indicator this would be when someone clicks on the
-		menu item for the indicator.
+	 * IndicateIndicator::display:
+	 * @arg0: The #IndicateIndicator object
+	 * 
+	 * Emitted when the user has clicked on this indicator.  In the
+	 * messaging indicator this would be when someone clicks on the
+	 * menu item for the indicator.
 	*/
 	signals[USER_DISPLAY] = g_signal_new(INDICATE_INDICATOR_SIGNAL_DISPLAY,
 	                                     G_TYPE_FROM_CLASS(class),
@@ -94,13 +94,13 @@ indicate_indicator_class_init (IndicateIndicatorClass * class)
 	                                     g_cclosure_marshal_VOID__UINT,
 	                                     G_TYPE_NONE, 1, G_TYPE_UINT);
 	/**
-		IndicateIndicator::hide:
-		@arg0: The #IndicateIndicator object
-
-		Emitted every time this indicator is hidden.  This
-		is mostly used by #IndicateServer.
-
-		Typically this results in an emition of #IndicateServer::indicator-removed.
+	 * IndicateIndicator::hide:
+	 * @arg0: The #IndicateIndicator object
+	 * 
+	 * Emitted every time this indicator is hidden.  This
+	 * is mostly used by #IndicateServer.
+	 * 
+	 * Typically this results in an emition of #IndicateServer::indicator-removed.
 	*/
 	signals[HIDE] = g_signal_new(INDICATE_INDICATOR_SIGNAL_HIDE,
 	                                     G_TYPE_FROM_CLASS(class),
@@ -110,13 +110,13 @@ indicate_indicator_class_init (IndicateIndicatorClass * class)
 	                                     g_cclosure_marshal_VOID__VOID,
 	                                     G_TYPE_NONE, 0);
 	/**
-		IndicateIndicator::show:
-		@arg0: The #IndicateIndicator object
-
-		Emitted every time this indicator is shown.  This
-		is mostly used by #IndicateServer.
-
-		Typically this results in an emition of #IndicateServer::indicator-added.
+	 * IndicateIndicator::show:
+	 * @arg0: The #IndicateIndicator object
+	 * 
+	 * Emitted every time this indicator is shown.  This
+	 * is mostly used by #IndicateServer.
+	 * 
+	 * Typically this results in an emition of #IndicateServer::indicator-added.
 	*/
 	signals[SHOW] = g_signal_new(INDICATE_INDICATOR_SIGNAL_SHOW,
 	                                     G_TYPE_FROM_CLASS(class),
@@ -126,14 +126,14 @@ indicate_indicator_class_init (IndicateIndicatorClass * class)
 	                                     g_cclosure_marshal_VOID__VOID,
 	                                     G_TYPE_NONE, 0);
 	/**
-		IndicateIndicator::modified:
-		@arg0: The #IndicateIndicator object
-		@arg1: The name of the property that changed.
-
-		Emitted every time an indicator property is changed.
-		This is mostly used by #IndicateServer.
-
-		Typically this results in an emition of #IndicateServer::indicator-modified.
+	 * IndicateIndicator::modified:
+	 * @arg0: The #IndicateIndicator object
+	 * @arg1: The name of the property that changed.
+	 * 
+	 * Emitted every time an indicator property is changed.
+	 * This is mostly used by #IndicateServer.
+	 * 
+	 * Typically this results in an emition of #IndicateServer::indicator-modified.
 	*/
 	signals[MODIFIED] = g_signal_new(INDICATE_INDICATOR_SIGNAL_MODIFIED,
 	                                     G_TYPE_FROM_CLASS(class),
@@ -143,13 +143,13 @@ indicate_indicator_class_init (IndicateIndicatorClass * class)
 	                                     g_cclosure_marshal_VOID__STRING,
 	                                     G_TYPE_NONE, 1, G_TYPE_STRING);
 	/**
-		IndicateIndicator::displayed:
-		@arg0: The #IndicateIndicator object
-		@arg1: Whether the indicator has been displayed
-
-		This is the signal that the indicator has been displayed, or
-		hidden by a listener.  In most cases, the signal will be that it
-		has been displayed as most folks don't go hiding it later.
+	 * IndicateIndicator::displayed:
+	 * @arg0: The #IndicateIndicator object
+	 * @arg1: Whether the indicator has been displayed
+	 * 
+	 * This is the signal that the indicator has been displayed, or
+	 * hidden by a listener.  In most cases, the signal will be that it
+	 * has been displayed as most folks don't go hiding it later.
 	*/
 	signals[DISPLAYED] = g_signal_new(INDICATE_INDICATOR_SIGNAL_DISPLAYED,
 	                                     G_TYPE_FROM_CLASS(class),
@@ -211,19 +211,19 @@ indicate_indicator_finalize (GObject * obj)
 }
 
 /**
-	indicate_indicator_get_type:
-
-	Gets a unique #GType for the #IndicateIndicator objects.
-
-	Return value: A unique #GType value.
+ * indicate_indicator_get_type:
+ * 
+ * Gets a unique #GType for the #IndicateIndicator objects.
+ * 
+ * Return value: A unique #GType value.
 */
 
 /**
-	indicate_indicator_new:
-
-	Builds a new indicator object using g_object_new().
-
-	Return value: A pointer to a new #IndicateIndicator object.
+ * indicate_indicator_new:
+ * 
+ * Builds a new indicator object using g_object_new().
+ * 
+ * Return value: A pointer to a new #IndicateIndicator object.
 */
 IndicateIndicator *
 indicate_indicator_new (void)
@@ -233,14 +233,14 @@ indicate_indicator_new (void)
 }
 
 /**
-	indicate_indicator_new_with_server:
-	@server: The server that should be associated with this indicator.
-
-	Builds a new indicator object using g_object_new() and sets
-	the server to the specified server.  Also, adds a reference
-	to the server.
-
-	Return value: A pointer to a new #IndicateIndicator object.
+ * indicate_indicator_new_with_server:
+ * @server: The server that should be associated with this indicator.
+ * 
+ * Builds a new indicator object using g_object_new() and sets
+ * the server to the specified server.  Also, adds a reference
+ * to the server.
+ * 
+ * Return value: A pointer to a new #IndicateIndicator object.
 */
 IndicateIndicator *
 indicate_indicator_new_with_server (IndicateServer * server)
@@ -255,12 +255,12 @@ indicate_indicator_new_with_server (IndicateServer * server)
 }
 
 /**
-	indicate_indicator_set_server:
-	@indicator: a #IndicateIndicator to act on
-	@server: the #IndicateServer which should be associated with @indicator
-
-	Defines which server this indicator must be associated to.  Also, adds a
-	reference to the server.
+ * indicate_indicator_set_server:
+ * @indicator: a #IndicateIndicator to act on
+ * @server: the #IndicateServer which should be associated with @indicator
+ * 
+ * Defines which server this indicator must be associated to.  Also, adds a
+ * reference to the server.
 */
 void
 indicate_indicator_set_server (IndicateIndicator * indicator, IndicateServer * server)
@@ -286,12 +286,12 @@ indicate_indicator_set_server (IndicateIndicator * indicator, IndicateServer * s
 
 
 /**
-	indicate_indicator_show:
-	@indicator: a #IndicateIndicator to act on
-
-	Shows this indicator on the bus.  If the #IndicateServer that it's
-	connected to is not shown itself this function will show the server
-	as well using #indicate_server_show.
+ * indicate_indicator_show:
+ * @indicator: a #IndicateIndicator to act on
+ * 
+ * Shows this indicator on the bus.  If the #IndicateServer that it's
+ * connected to is not shown itself this function will show the server
+ * as well using #indicate_server_show.
 */
 void
 indicate_indicator_show (IndicateIndicator * indicator)
@@ -313,11 +313,11 @@ indicate_indicator_show (IndicateIndicator * indicator)
 }
 
 /**
-	indicate_indicator_hide:
-	@indicator: a #IndicateIndicator to act on
-
-	Hides the indicator from the bus.  Does not effect the
-	indicator's #IndicateServer in any way.
+ * indicate_indicator_hide:
+ * @indicator: a #IndicateIndicator to act on
+ * 
+ * Hides the indicator from the bus.  Does not effect the
+ * indicator's #IndicateServer in any way.
 */
 void
 indicate_indicator_hide (IndicateIndicator * indicator)
@@ -337,12 +337,12 @@ indicate_indicator_hide (IndicateIndicator * indicator)
 }
 
 /**
-	indicate_indicator_is_visible:
-	@indicator: a #IndicateIndicator to act on
-
-	Checkes the visibility status of @indicator.
-
-	Return value: %TRUE if the indicator is visible else %FALSE.
+ * indicate_indicator_is_visible:
+ * @indicator: a #IndicateIndicator to act on
+ * 
+ * Checkes the visibility status of @indicator.
+ * 
+ * Return value: %TRUE if the indicator is visible else %FALSE.
 */
 gboolean
 indicate_indicator_is_visible (IndicateIndicator * indicator)
@@ -353,13 +353,13 @@ indicate_indicator_is_visible (IndicateIndicator * indicator)
 }
 
 /**
-	indicate_indicator_get_id:
-	@indicator: a #IndicateIndicator to act on
-
-	Gets the ID value of the @indicator.
-
-	Return value: The ID of the indicator.  Can not be zero.
-		Zero represents an error.
+ * indicate_indicator_get_id:
+ * @indicator: a #IndicateIndicator to act on
+ * 
+ * Gets the ID value of the @indicator.
+ * 
+ * Return value: The ID of the indicator.  Can not be zero.
+ * Zero represents an error.
 */
 guint
 indicate_indicator_get_id (IndicateIndicator * indicator)
@@ -370,13 +370,13 @@ indicate_indicator_get_id (IndicateIndicator * indicator)
 }
 
 /**
-	indicate_indicator_get_server:
-	@indicator: a #IndicateIndicator to act on
-
-	Gets the server of the @indicator.
-
-	Return value: The server associated with the indicator
-		or NULL if error.
+ * indicate_indicator_get_server:
+ * @indicator: a #IndicateIndicator to act on
+ * 
+ * Gets the server of the @indicator.
+ * 
+ * Return value: (transfer none): The server associated with the indicator
+ * or NULL if error.
 */
 IndicateServer *
 indicate_indicator_get_server (IndicateIndicator * indicator)
@@ -387,13 +387,13 @@ indicate_indicator_get_server (IndicateIndicator * indicator)
 }
 
 /**
-	indicate_indicator_user_display:
-	@indicator: a #IndicateIndicator to act on
-	@timestamp: The time that the event happened
-
-	Emits the #IndicateIndicator::user-display signal simliar to a user
-	clicking on @indicator over the bus.  Signal will not be sent if the
-	@indicator is not visible.
+ * indicate_indicator_user_display:
+ * @indicator: a #IndicateIndicator to act on
+ * @timestamp: The time that the event happened
+ * 
+ * Emits the #IndicateIndicator::user-display signal simliar to a user
+ * clicking on @indicator over the bus.  Signal will not be sent if the
+ * @indicator is not visible.
 */
 void
 indicate_indicator_user_display (IndicateIndicator * indicator, guint timestamp)
@@ -408,16 +408,16 @@ indicate_indicator_user_display (IndicateIndicator * indicator, guint timestamp)
 }
 
 /**
-	indicate_indicator_set_property:
-	@indicator: a #IndicateIndicator to act on
-	@key: name of the property
-	@data: value of the property
-
-	Sets a simple string property on @indicator.  If the property
-	had previously been set it will replace it with the new value,
-	otherwise it will create the property.  This will include an
-	emition of #IndicateIndicator::modified if the property value
-	was changed.
+ * indicate_indicator_set_property:
+ * @indicator: a #IndicateIndicator to act on
+ * @key: name of the property
+ * @data: value of the property
+ * 
+ * Sets a simple string property on @indicator.  If the property
+ * had previously been set it will replace it with the new value,
+ * otherwise it will create the property.  This will include an
+ * emition of #IndicateIndicator::modified if the property value
+ * was changed.
 */
 void
 indicate_indicator_set_property (IndicateIndicator * indicator, const gchar * key, const gchar * data)
@@ -432,15 +432,15 @@ indicate_indicator_set_property (IndicateIndicator * indicator, const gchar * ke
 }
 
 /**
-	indicate_indicator_set_property_time:
-	@indicator: a #IndicateIndicator to act on
-	@key: name of the property
-	@time: time to set property with
-
-	This is a helper function that wraps around #indicate_indicator_set_property
-	but takes an #GTimeVal parameter.  It then takes the @data
-	parameter converts it to an ISO 8601 time string and
-	uses that data to call #indicate_indicator_set_property.
+ * indicate_indicator_set_property_time:
+ * @indicator: a #IndicateIndicator to act on
+ * @key: name of the property
+ * @time: time to set property with
+ * 
+ * This is a helper function that wraps around #indicate_indicator_set_property
+ * but takes an #GTimeVal parameter.  It then takes the @data
+ * parameter converts it to an ISO 8601 time string and
+ * uses that data to call #indicate_indicator_set_property.
 */
 void
 indicate_indicator_set_property_time (IndicateIndicator * indicator, const gchar * key, GTimeVal * time)
@@ -454,14 +454,14 @@ indicate_indicator_set_property_time (IndicateIndicator * indicator, const gchar
 }
 
 /**
-	indicate_indicator_set_property_int:
-	@indicator: a #IndicateIndicator to act on
-	@key: name of the property
-	@value: integer to set property with
-
-	This is a helper function that wraps around #indicate_indicator_set_property
-	but takes an integer property and turns into a string and
-	uses that data to call #indicate_indicator_set_property.
+ * indicate_indicator_set_property_int:
+ * @indicator: a #IndicateIndicator to act on
+ * @key: name of the property
+ * @value: integer to set property with
+ * 
+ * This is a helper function that wraps around #indicate_indicator_set_property
+ * but takes an integer property and turns into a string and
+ * uses that data to call #indicate_indicator_set_property.
 */
 void
 indicate_indicator_set_property_int (IndicateIndicator * indicator, const gchar * key, gint value)
@@ -480,14 +480,14 @@ indicate_indicator_set_property_int (IndicateIndicator * indicator, const gchar
 }
 
 /**
-	indicate_indicator_set_property_bool:
-	@indicator: a #IndicateIndicator to act on
-	@key: name of the property
-	@value: integer to set property with
-
-	This is a helper function that wraps around #indicate_indicator_set_property
-	but takes a boolean property and turns into a string and
-	uses that data to call #indicate_indicator_set_property.
+ * indicate_indicator_set_property_bool:
+ * @indicator: a #IndicateIndicator to act on
+ * @key: name of the property
+ * @value: integer to set property with
+ * 
+ * This is a helper function that wraps around #indicate_indicator_set_property
+ * but takes a boolean property and turns into a string and
+ * uses that data to call #indicate_indicator_set_property.
 */
 void
 indicate_indicator_set_property_bool (IndicateIndicator * indicator, const gchar * key, gboolean value)
@@ -513,14 +513,14 @@ indicate_indicator_set_property_variant (IndicateIndicator * indicator, const gc
 }
 
 /**
-	indicate_indicator_get_property:
-	@indicator: a #IndicateIndicator to act on
-	@key: name of the property
-
-	Returns the value that is set for a property or %NULL if that
-	property is not set.
-
-	Return value: A constant string or NULL.
+ * indicate_indicator_get_property:
+ * @indicator: a #IndicateIndicator to act on
+ * @key: name of the property
+ * 
+ * Returns the value that is set for a property or %NULL if that
+ * property is not set.
+ * 
+ * Return value: A constant string or NULL.
 */
 const gchar *
 indicate_indicator_get_property (IndicateIndicator * indicator, const gchar * key)
@@ -609,13 +609,13 @@ list_properties (IndicateIndicator * indicator)
 }
 
 /**
-	indicate_indicator_set_displayed:
-	@indicator: The #IndicateIndicator to configure
-	@displayed: Whether or not the indicator is visible to users
-
-	Sets whether or not the indicator is visible to the user from
-	a listener.  This does not include things like whether the menu
-	is open, but more whether it's in the menu to be found.
+ * indicate_indicator_set_displayed:
+ * @indicator: The #IndicateIndicator to configure
+ * @displayed: Whether or not the indicator is visible to users
+ * 
+ * Sets whether or not the indicator is visible to the user from
+ * a listener.  This does not include things like whether the menu
+ * is open, but more whether it's in the menu to be found.
 */
 void
 indicate_indicator_set_displayed (IndicateIndicator * indicator, gboolean displayed)
@@ -632,13 +632,13 @@ indicate_indicator_set_displayed (IndicateIndicator * indicator, gboolean displa
 }
 
 /**
-	indicate_indicator_get_displayed:
-	@indicator: The #IndicateIndicator to query
-
-	Checks to see if the indicator is visible to users in some way.
-
-	Return value: Whether or not this indicator can be seen by a user
-		or not.
+ * indicate_indicator_get_displayed:
+ * @indicator: The #IndicateIndicator to query
+ * 
+ * Checks to see if the indicator is visible to users in some way.
+ * 
+ * Return value: Whether or not this indicator can be seen by a user
+ * or not.
 */
 gboolean
 indicate_indicator_get_displayed (IndicateIndicator * indicator)
