@@ -61,12 +61,12 @@ typedef struct _IndicateIndicator IndicateIndicator;
 typedef struct _IndicateIndicatorClass IndicateIndicatorClass;
 
 /**
-	IndicateIndicator:
-
-	The indicator object represents a single item that is shared over the
-	indicator bus.  This could be something like one IM, one e-mail or 
-	a single system update.  It should be accessed only through its
-	accessors.
+ * IndicateIndicator:
+ * 
+ * The indicator object represents a single item that is shared over the
+ * indicator bus.  This could be something like one IM, one e-mail or 
+ * a single system update.  It should be accessed only through its
+ * accessors.
 */
 struct _IndicateIndicator {
 	GObject parent;
@@ -183,29 +183,29 @@ void indicate_indicator_set_displayed (IndicateIndicator * indicator, gboolean d
 gboolean indicate_indicator_get_displayed (IndicateIndicator * indicator);
 
 /**
-	SECTION:indicator
-	@short_description: A representation of state for applications
-	@stability: Unstable
-	@include: libindicate/indicator.h
-
-	An indicator is designed to represent a single instance of something
-	in your application.  So this might be an IM or an e-mail mail box
-	or any other thing that is a small unit of information to pass on
-	to the user.
-
-	Indicators make no promises about how they are preceived by the
-	user, it's up to the listener to represent them in an intutive and
-	visually appealling way.  But, what we can do is provide information
-	on the indicator to provide enough information for the listener
-	to do that.
-
-	Mostly this is done through properties.
-
-	It may be that some users don't want to create objects for every
-	indicator as it could be a lot of overhead if there are large numbers
-	and there is already a data structure representing them all.  In that
-	case it is recommended that you ignore the #IndicateIndicator object
-	tree in general and move to subclassing #IndicateServer directly.
+ * SECTION:indicator
+ * @short_description: A representation of state for applications
+ * @stability: Unstable
+ * @include: libindicate/indicator.h
+ * 
+ * An indicator is designed to represent a single instance of something
+ * in your application.  So this might be an IM or an e-mail mail box
+ * or any other thing that is a small unit of information to pass on
+ * to the user.
+ * 
+ * Indicators make no promises about how they are preceived by the
+ * user, it's up to the listener to represent them in an intutive and
+ * visually appealling way.  But, what we can do is provide information
+ * on the indicator to provide enough information for the listener
+ * to do that.
+ * 
+ * Mostly this is done through properties.
+ * 
+ * It may be that some users don't want to create objects for every
+ * indicator as it could be a lot of overhead if there are large numbers
+ * and there is already a data structure representing them all.  In that
+ * case it is recommended that you ignore the #IndicateIndicator object
+ * tree in general and move to subclassing #IndicateServer directly.
 */
 
 G_END_DECLS
