@@ -388,12 +388,12 @@ bus_method_call (GDBusConnection * connection, const gchar * sender, const gchar
 }
 
 /**
-	indicate_listener_new:
-
-	Creates a new Listener object.  Does not set this to the default
-	listener object.
-
-	Return value: A new listener object.
+ * indicate_listener_new:
+ * 
+ * Creates a new Listener object.  Does not set this to the default
+ * listener object.
+ * 
+ * Return value: A new listener object.
 */
 IndicateListener *
 indicate_listener_new (void)
@@ -407,17 +407,17 @@ indicate_listener_new (void)
 static IndicateListener * default_indicate_listener = NULL;
 
 /**
-	indcate_listener_ref_default:
-
-	Looks for the default listener, and if it doesn't exist it'll
-	allocate a new one and mark it the default.  This is what most
-	programs should use rather than #indicate_listener_new because
-	it is rare that anyone would need more than a single listener.
-	This function does increase the ref count on the object so anyone
-	calling it should unref thier instance of the default listener.
-
-	Return value: The default instance of #IndicateListener for the
-		program.
+ * indicate_listener_ref_default:
+ * 
+ * Looks for the default listener, and if it doesn't exist it'll
+ * allocate a new one and mark it the default.  This is what most
+ * programs should use rather than #indicate_listener_new because
+ * it is rare that anyone would need more than a single listener.
+ * This function does increase the ref count on the object so anyone
+ * calling it should unref thier instance of the default listener.
+ * 
+ * Return value: (transfer full): The default instance of #IndicateListener for the
+ * program.
 */
 IndicateListener *
 indicate_listener_ref_default (void)
@@ -1039,19 +1039,19 @@ get_property_helper (IndicateListener * listener, IndicateListenerServer * serve
 }
 
 /**
-	indicate_listener_get_property_variant:
-	@listener: The #IndicateListener representing the connection
-	@server: The server that the indicator is on
-	@indicator: Which indicator is being queried
-	@property: Name of the property to get
-	@callback: The callback function to call with the data
-	@data: Arbitrary data to give the callback
-
-	A function to get a property from an indicator on a server
-	and bring it back locally.  This wraps all the hassle of using
-	the DBus API and makes it pretty easy to get properties.
-
-	This function gets the raw GVariant data, without any conversion.
+ * indicate_listener_get_property_variant:
+ * @listener: The #IndicateListener representing the connection
+ * @server: The server that the indicator is on
+ * @indicator: Which indicator is being queried
+ * @property: Name of the property to get
+ * @callback: The callback function to call with the data
+ * @data: Arbitrary data to give the callback
+ * 
+ * A function to get a property from an indicator on a server
+ * and bring it back locally.  This wraps all the hassle of using
+ * the DBus API and makes it pretty easy to get properties.
+ * 
+ * This function gets the raw GVariant data, without any conversion.
 */
 void
 indicate_listener_get_property_variant (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, indicate_listener_get_property_variant_cb callback, gpointer data)
@@ -1060,17 +1060,17 @@ indicate_listener_get_property_variant (IndicateListener * listener, IndicateLis
 }
 
 /**
-	indicate_listener_get_property:
-	@listener: The #IndicateListener representing the connection
-	@server: The server that the indicator is on
-	@indicator: Which indicator is being queried
-	@property: Name of the property to get
-	@callback: The callback function to call with the data
-	@data: Arbitrary data to give the callback
-
-	A function to get a property from an indicator on a server
-	and bring it back locally.  This wraps all the hassle of using
-	the DBus API and makes it pretty easy to get properties.
+ * indicate_listener_get_property:
+ * @listener: The #IndicateListener representing the connection
+ * @server: The server that the indicator is on
+ * @indicator: Which indicator is being queried
+ * @property: Name of the property to get
+ * @callback: The callback function to call with the data
+ * @data: Arbitrary data to give the callback
+ * 
+ * A function to get a property from an indicator on a server
+ * and bring it back locally.  This wraps all the hassle of using
+ * the DBus API and makes it pretty easy to get properties.
 */
 void
 indicate_listener_get_property (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, indicate_listener_get_property_cb callback, gpointer data)
@@ -1079,21 +1079,21 @@ indicate_listener_get_property (IndicateListener * listener, IndicateListenerSer
 }
 
 /**
-	indicate_listener_get_property_time:
-	@listener: The #IndicateListener representing the connection
-	@server: The server that the indicator is on
-	@indicator: Which indicator is being queried
-	@property: Name of the property to get
-	@callback: The callback function to call with the data
-	@data: Arbitrary data to give the callback
-
-	A function to get a property from an indicator on a server
-	and bring it back locally.  This wraps all the hassle of using
-	the DBus API and makes it pretty easy to get properties.
-
-	Very similar to #indicate_listener_get_property but converts
-	the final value into a GTimeVal for easy (and type-safe)
-	usage by listeners.
+ * indicate_listener_get_property_time:
+ * @listener: The #IndicateListener representing the connection
+ * @server: The server that the indicator is on
+ * @indicator: Which indicator is being queried
+ * @property: Name of the property to get
+ * @callback: The callback function to call with the data
+ * @data: Arbitrary data to give the callback
+ * 
+ * A function to get a property from an indicator on a server
+ * and bring it back locally.  This wraps all the hassle of using
+ * the DBus API and makes it pretty easy to get properties.
+ * 
+ * Very similar to #indicate_listener_get_property but converts
+ * the final value into a GTimeVal for easy (and type-safe)
+ * usage by listeners.
 */
 void
 indicate_listener_get_property_time (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, indicate_listener_get_property_time_cb callback, gpointer data)
@@ -1102,21 +1102,21 @@ indicate_listener_get_property_time (IndicateListener * listener, IndicateListen
 }
 
 /**
-	indicate_listener_get_property_int:
-	@listener: The #IndicateListener representing the connection
-	@server: The server that the indicator is on
-	@indicator: Which indicator is being queried
-	@property: Name of the property to get
-	@callback: The callback function to call with the data
-	@data: Arbitrary data to give the callback
-
-	A function to get a property from an indicator on a server
-	and bring it back locally.  This wraps all the hassle of using
-	the DBus API and makes it pretty easy to get properties.
-
-	Very similar to #indicate_listener_get_property but converts
-	the final value into a gint for easy (and type-safe)
-	usage by listeners.
+ * indicate_listener_get_property_int:
+ * @listener: The #IndicateListener representing the connection
+ * @server: The server that the indicator is on
+ * @indicator: Which indicator is being queried
+ * @property: Name of the property to get
+ * @callback: The callback function to call with the data
+ * @data: Arbitrary data to give the callback
+ * 
+ * A function to get a property from an indicator on a server
+ * and bring it back locally.  This wraps all the hassle of using
+ * the DBus API and makes it pretty easy to get properties.
+ * 
+ * Very similar to #indicate_listener_get_property but converts
+ * the final value into a gint for easy (and type-safe)
+ * usage by listeners.
 */
 void
 indicate_listener_get_property_int (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, indicate_listener_get_property_int_cb callback, gpointer data)
@@ -1125,21 +1125,21 @@ indicate_listener_get_property_int (IndicateListener * listener, IndicateListene
 }
 
 /**
-	indicate_listener_get_property_bool:
-	@listener: The #IndicateListener representing the connection
-	@server: The server that the indicator is on
-	@indicator: Which indicator is being queried
-	@property: Name of the property to get
-	@callback: The callback function to call with the data
-	@data: Arbitrary data to give the callback
-
-	A function to get a property from an indicator on a server
-	and bring it back locally.  This wraps all the hassle of using
-	the DBus API and makes it pretty easy to get properties.
-
-	Very similar to #indicate_listener_get_property but converts
-	the final value into a gboolean for easy (and type-safe)
-	usage by listeners.
+ * indicate_listener_get_property_bool:
+ * @listener: The #IndicateListener representing the connection
+ * @server: The server that the indicator is on
+ * @indicator: Which indicator is being queried
+ * @property: Name of the property to get
+ * @callback: The callback function to call with the data
+ * @data: Arbitrary data to give the callback
+ * 
+ * A function to get a property from an indicator on a server
+ * and bring it back locally.  This wraps all the hassle of using
+ * the DBus API and makes it pretty easy to get properties.
+ * 
+ * Very similar to #indicate_listener_get_property but converts
+ * the final value into a gboolean for easy (and type-safe)
+ * usage by listeners.
 */
 void
 indicate_listener_get_property_bool (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gchar * property, indicate_listener_get_property_bool_cb callback, gpointer data)
@@ -1157,10 +1157,38 @@ listener_display_cb (GObject * object, GAsyncResult * res, gpointer user_data)
 
 	if (error != NULL) {
 		g_warning("Listener display caused an error: %s", error->message);
+		g_error_free(error);
 	}
 	return;
 }
 
+/**
+ * indicate_listener_get_servers:
+ * @listener: The listener to look on
+ *
+ * Returns all the servers that this listener currently
+ * knows about.
+ *
+ * Return value: (transfer container) (element-type IndicatorListenerServer):
+ * A list of servers.
+ */
+GList *
+indicate_listener_get_servers (IndicateListener * listener)
+{
+	g_return_val_if_fail(INDICATE_IS_LISTENER(listener), NULL);
+	IndicateListenerPrivate * priv = INDICATE_LISTENER_GET_PRIVATE(listener);
+
+	GList * output = NULL;
+	GList * pntr;
+
+	for (pntr = priv->proxies; pntr != NULL; pntr = g_list_next(pntr)) {
+		proxy_t * proxy = (proxy_t *)pntr->data;
+		output = g_list_prepend(output, &proxy->server);
+	}
+
+	return output;
+}
+
 void
 indicate_listener_display (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, guint timestamp)
 {
@@ -1186,21 +1214,22 @@ listener_displayed_cb (GObject * object, GAsyncResult * res, gpointer user_data)
 
 	if (error != NULL) {
 		g_warning("Listener displayed caused an error: %s", error->message);
+		g_error_free(error);
 	}
 	return;
 }
 
 /**
-	indicate_listener_displayed:
-	@listener: The #IndicateListener representing the connection
-	@server: The server that the indicator is on
-	@indicator: Which indicator is being displayed
-	@displayed: Whether it's being displayed or hidden
-
-	This function tells the client whether we're showing this indicator
-	to the user.  This doesn't mean that it's necissarilly visible right
-	now, but more that there is a way for the user to get to this item
-	individually.
+ * indicate_listener_displayed:
+ * @listener: The #IndicateListener representing the connection
+ * @server: The server that the indicator is on
+ * @indicator: Which indicator is being displayed
+ * @displayed: Whether it's being displayed or hidden
+ * 
+ * This function tells the client whether we're showing this indicator
+ * to the user.  This doesn't mean that it's necissarilly visible right
+ * now, but more that there is a way for the user to get to this item
+ * individually.
 */
 void
 indicate_listener_displayed (IndicateListener * listener, IndicateListenerServer * server, IndicateListenerIndicator * indicator, gboolean displayed)
@@ -1355,6 +1384,44 @@ indicate_listener_server_get_menu (IndicateListener * listener, IndicateListener
 	return get_server_property(listener, server, callback, NULL, "menu", data);
 }
 
+/**
+ * indicate_listener_server_get_indicators:
+ * @listener: The listener for the server
+ * @server: Which server for the indicators
+ *
+ * Returns all of the indicators that are currently known to
+ * exist on this server.
+ *
+ * Return value: (transfer container) (element-type IndicateListenerIndicator):
+ * A list of indicators.
+ */
+GList *
+indicate_listener_server_get_indicators (IndicateListener * listener, IndicateListenerServer * server)
+{
+	g_return_val_if_fail(INDICATE_IS_LISTENER(listener), NULL);
+	g_return_val_if_fail(server != NULL, NULL);
+
+	IndicateListenerPrivate * priv = INDICATE_LISTENER_GET_PRIVATE(listener);
+
+	proxy_t searchitem;
+	searchitem.name = server->name;
+	searchitem.connection = server->connection;
+
+	GList * proxyitem = g_list_find_custom(priv->proxies, &searchitem, proxy_t_equal);
+	if (proxyitem == NULL) {
+		g_warning("Unable to find proxy item for server %s", server->name);
+		return NULL;
+	}
+
+	proxy_t * item = (proxy_t *)proxyitem->data;
+
+	if (item->indicators == NULL) {
+		/* We have no indicators for sure, so this is a valid return */
+		return NULL;
+	}
+
+	return g_hash_table_get_keys(item->indicators);
+}
 
 const gchar *
 indicate_listener_server_get_dbusname (IndicateListenerServer * server)
@@ -1469,16 +1536,16 @@ indicate_listener_indicator_get_gtype (void)
 }
 
 /**
-	indicate_listener_set_default_max_indicators:
-	@listener: Instance of #IndicateListener to set on.
-	@max: The new default number of max indicators.
-
-	This function sets the number that is given to new servers
-	when they start for the max number of indicators that you want
-	to see.  The client should enforce this number.
-
-	Note: This function WILL NOT reconfigure already recognized
-	      servers.  It only affects new servers.
+ * indicate_listener_set_default_max_indicators:
+ * @listener: Instance of #IndicateListener to set on.
+ * @max: The new default number of max indicators.
+ * 
+ * This function sets the number that is given to new servers
+ * when they start for the max number of indicators that you want
+ * to see.  The client should enforce this number.
+ * 
+ * Note: This function WILL NOT reconfigure already recognized
+ * servers.  It only affects new servers.
 */
 void
 indicate_listener_set_default_max_indicators (IndicateListener * listener, gint max)
@@ -1490,16 +1557,16 @@ indicate_listener_set_default_max_indicators (IndicateListener * listener, gint
 }
 
 /**
-	indicate_listener_set_server_max_indicators:
-	@listener: Instance of #IndicateListener to set on.
-	@server: Server that the new max should be set on.
-	@max: The new number of max indicators.
-
-	This function changes the max number of indicators that
-	a server should send.  If the number is different than the
-	previous number a signal will be sent to the application to
-	adjust then number of indicators that they have.  This is
-	sent asynchronously.
+ * indicate_listener_set_server_max_indicators:
+ * @listener: Instance of #IndicateListener to set on.
+ * @server: Server that the new max should be set on.
+ * @max: The new number of max indicators.
+ * 
+ * This function changes the max number of indicators that
+ * a server should send.  If the number is different than the
+ * previous number a signal will be sent to the application to
+ * adjust then number of indicators that they have.  This is
+ * sent asynchronously.
 */
 void
 indicate_listener_set_server_max_indicators (IndicateListener * listener, IndicateListenerServer * server, gint max)
