@@ -261,13 +261,13 @@ indicate_server_class_init (IndicateServerClass * class)
 	                                        _indicate_marshal_VOID__UINT,
 	                                        G_TYPE_NONE, 1, G_TYPE_UINT);
 	/**
-		IndicateServer::indicator-modified:
-		@arg0: The #IndicateServer object
-		@arg1: The #IndicateIndicator ID number
-		@arg2: The name of the property modified
-
-		Emitted every time that a property on an indicator changes
-		and it is visible to the world.  This results in a signal on DBus.
+	 * IndicateServer::indicator-modified:
+	 * @arg0: The #IndicateServer object
+	 * @arg1: The #IndicateIndicator ID number
+	 * @arg2: The name of the property modified
+	 *
+	 * Emitted every time that a property on an indicator changes
+	 * and it is visible to the world.  This results in a signal on DBus.
 	*/
 	signals[INDICATOR_MODIFIED] = g_signal_new(INDICATE_SERVER_SIGNAL_INDICATOR_MODIFIED,
 	                                        G_TYPE_FROM_CLASS (class),
@@ -277,14 +277,14 @@ indicate_server_class_init (IndicateServerClass * class)
 	                                        _indicate_marshal_VOID__UINT_STRING,
 	                                        G_TYPE_NONE, 2, G_TYPE_UINT, G_TYPE_STRING);
 	/**
-		IndicateServer::server-show:
-		@arg0: The #IndicateServer object
-		@arg1: The type of the server
-
-		Emitted when a server comes onto DBus by being shown.  This
-		is typically when listeners start reacting to the application's
-		indicators.  This results in a signal on DBus.
-	*/
+	  * IndicateServer::server-show:
+	  * @arg0: The #IndicateServer object
+	  * @arg1: The type of the server
+	  *
+	  * Emitted when a server comes onto DBus by being shown.  This
+	  * is typically when listeners start reacting to the application's
+	  * indicators.  This results in a signal on DBus.
+ 	  */
 	signals[SERVER_SHOW] = g_signal_new(INDICATE_SERVER_SIGNAL_SERVER_SHOW,
 	                                        G_TYPE_FROM_CLASS (class),
 	                                        G_SIGNAL_RUN_LAST,
@@ -293,13 +293,13 @@ indicate_server_class_init (IndicateServerClass * class)
 	                                        g_cclosure_marshal_VOID__STRING,
 	                                        G_TYPE_NONE, 1, G_TYPE_STRING);
 	/**
-		IndicateServer::server-hide:
-		@arg0: The #IndicateServer object
-		@arg1: The type of the server
-
-		Emitted when a server removes itself from DBus.  This results
-		in a signal on DBus.
-	*/
+	 * IndicateServer::server-hide:
+	 * @arg0: The #IndicateServer object
+	 * @arg1: The type of the server
+	 *
+	 * Emitted when a server removes itself from DBus.  This results
+	 * in a signal on DBus.
+	 */
 	signals[SERVER_HIDE] = g_signal_new(INDICATE_SERVER_SIGNAL_SERVER_HIDE,
 	                                        G_TYPE_FROM_CLASS (class),
 	                                        G_SIGNAL_RUN_LAST,
@@ -308,14 +308,14 @@ indicate_server_class_init (IndicateServerClass * class)
 	                                        g_cclosure_marshal_VOID__STRING,
 	                                        G_TYPE_NONE, 1, G_TYPE_STRING);
 	/**
-		IndicateServer::server-display:
-		@arg0: The #IndicateServer object
-		@arg1: Timestamp of the show event
-
-		Emitted when a listener signals that the server itself should be
-		displayed.  This signal is caused by a user clicking on the application
-		item in the Messaging Menu.  This signal is emitted by DBus.
-	*/
+	 * IndicateServer::server-display:
+	 * @arg0: The #IndicateServer object
+	 * @arg1: Timestamp of the show event
+	 *
+	 * Emitted when a listener signals that the server itself should be
+	 * displayed.  This signal is caused by a user clicking on the application
+	 * item in the Messaging Menu.  This signal is emitted by DBus.
+	 */
 	signals[SERVER_DISPLAY] = g_signal_new(INDICATE_SERVER_SIGNAL_SERVER_DISPLAY,
 	                                        G_TYPE_FROM_CLASS (class),
 	                                        G_SIGNAL_RUN_LAST,
@@ -324,13 +324,13 @@ indicate_server_class_init (IndicateServerClass * class)
 	                                        g_cclosure_marshal_VOID__UINT,
 	                                        G_TYPE_NONE, 1, G_TYPE_UINT);
 	/**
-		IndicateServer::interest-added:
-		@arg0: The #IndicateServer object
-		@arg1: The interest that was added from #IndicateInterests
-
-		Emitted when a listener signals that they are interested in
-		this server for a particular reason.  This signal is emitted by DBus.
-	*/
+	 * IndicateServer::interest-added:
+	 * @arg0: The #IndicateServer object
+	 * @arg1: The interest that was added from #IndicateInterests
+	 *
+	 * Emitted when a listener signals that they are interested in
+	 * this server for a particular reason.  This signal is emitted by DBus.
+	 */
 	signals[INTEREST_ADDED] = g_signal_new(INDICATE_SERVER_SIGNAL_INTEREST_ADDED,
 	                                        G_TYPE_FROM_CLASS (class),
 	                                        G_SIGNAL_RUN_LAST,
@@ -339,17 +339,17 @@ indicate_server_class_init (IndicateServerClass * class)
 	                                        g_cclosure_marshal_VOID__UINT,
 	                                        G_TYPE_NONE, 1, G_TYPE_UINT);
 	/**
-		IndicateServer::interest-removed:
-		@arg0: The #IndicateServer object
-		@arg1: The interest that was removed from #IndicateInterests
-
-		Emitted when a listener signals that they are no longer interested in
-		this server for a particular reason.  This signal is emitted by DBus.
-
-		@note This signal is also emitted after a timeout when the object
-		is created with @arg1 set to #INDICATOR_INTREST_NONE if no one has
-		shown any interest in the server.
-	*/
+	 * IndicateServer::interest-removed:
+	 * @arg0: The #IndicateServer object
+	 * @arg1: The interest that was removed from #IndicateInterests
+	 *
+	 * Emitted when a listener signals that they are no longer interested in
+	 * this server for a particular reason.  This signal is emitted by DBus.
+	 *
+	 * @note This signal is also emitted after a timeout when the object
+	 * is created with @arg1 set to #INDICATOR_INTREST_NONE if no one has
+	 * shown any interest in the server.
+	 */
 	signals[INTEREST_REMOVED] = g_signal_new(INDICATE_SERVER_SIGNAL_INTEREST_REMOVED,
 	                                        G_TYPE_FROM_CLASS (class),
 	                                        G_SIGNAL_RUN_LAST,
@@ -358,13 +358,13 @@ indicate_server_class_init (IndicateServerClass * class)
 	                                        g_cclosure_marshal_VOID__UINT,
 	                                        G_TYPE_NONE, 1, G_TYPE_UINT);
 	/**
-		IndicateServer::max-indicators-changed:
-		@arg0: The #IndicateServer object
-		@arg1: The new max number of indicators
-
-		Emitted when a listener either specifies their max number
-		to be higher, or at all.  The default is -1 or infinite.
-	*/
+	 * IndicateServer::max-indicators-changed:
+	 * @arg0: The #IndicateServer object
+	 * @arg1: The new max number of indicators
+	 *
+	 * Emitted when a listener either specifies their max number
+	 * to be higher, or at all.  The default is -1 or infinite.
+	 */
 	signals[MAX_INDICATORS_CHANGED] = g_signal_new(INDICATE_SERVER_SIGNAL_MAX_INDICATORS_CHANGED,
 	                                        G_TYPE_FROM_CLASS (class),
 	                                        G_SIGNAL_RUN_LAST,
@@ -373,13 +373,13 @@ indicate_server_class_init (IndicateServerClass * class)
 	                                        g_cclosure_marshal_VOID__INT,
 	                                        G_TYPE_NONE, 1, G_TYPE_INT);
 	/**
-		IndicateServer::server-count-changed:
-		@arg0: The #IndicateServer object
-		@arg1: The count variable on the server changed.
-
-		Emitted when the count property of the server changes
-		to a new value.
-	*/
+	 * IndicateServer::server-count-changed:
+	 * @arg0: The #IndicateServer object
+	 * @arg1: The count variable on the server changed.
+	 *
+	 * Emitted when the count property of the server changes
+	 * to a new value.
+	 */
 	signals[SERVER_COUNT_CHANGED] = g_signal_new(INDICATE_SERVER_SIGNAL_SERVER_COUNT_CHANGED,
 	                                        G_TYPE_FROM_CLASS (class),
 	                                        G_SIGNAL_RUN_LAST,
@@ -862,15 +862,15 @@ indicate_server_error_quark (void)
 }
 
 /**
-	indicate_server_show:
-	@server: The #IndicateServer to be shown
-
-	This function exports the object onto DBus and shows it
-	to the world.  This will be the start of it receiving external
-	signals from DBus.  It is likely that, if there are listeners
-	running, there will several #IndicateServer::interest-added
-	signals coming shortly after this function.  This function
-	emits the #IndicateServer::server-added signal across the bus.
+ * indicate_server_show:
+ * @server: The #IndicateServer to be shown
+ * 
+ * This function exports the object onto DBus and shows it
+ * to the world.  This will be the start of it receiving external
+ * signals from DBus.  It is likely that, if there are listeners
+ * running, there will several #IndicateServer::interest-added
+ * signals coming shortly after this function.  This function
+ * emits the #IndicateServer::server-added signal across the bus.
 */
 void
 indicate_server_show (IndicateServer * server)
@@ -921,14 +921,14 @@ indicate_server_show (IndicateServer * server)
 }
 
 /**
-	indicate_server_hide:
-	@server: The #IndicateServer to hide.
-
-	This function hides the server from DBus so that it does
-	not get signals anymore.  This causes the signal #IndicateServer::server-hide
-	to be sent across the bus for all listeners.  Also internally
-	it will signal #IndicateServer::interest-removed for all the
-	interests that were currently set for this server.
+ * indicate_server_hide:
+ * @server: The #IndicateServer to hide.
+ * 
+ * This function hides the server from DBus so that it does
+ * not get signals anymore.  This causes the signal #IndicateServer::server-hide
+ * to be sent across the bus for all listeners.  Also internally
+ * it will signal #IndicateServer::interest-removed for all the
+ * interests that were currently set for this server.
 */
 void
 indicate_server_hide (IndicateServer * server)
@@ -1298,14 +1298,14 @@ indicator_modified_cb (IndicateIndicator * indicator, gchar * property, Indicate
 }
 
 /**
-	indicate_server_add_indicator:
-	@server: The #IndicateServer to add the #IndicateIndictor to.
-	@indicator: The #IndicateIndicator to add.
-
-	This function adds an indicator @indicator to the list that are
-	watched by the server @server.  This means that signals that are
-	emitted by the indicator will be picked up and passed via DBus onto
-	listeners of the application.
+ * indicate_server_add_indicator:
+ * @server: The #IndicateServer to add the #IndicateIndictor to.
+ * @indicator: The #IndicateIndicator to add.
+ * 
+ * This function adds an indicator @indicator to the list that are
+ * watched by the server @server.  This means that signals that are
+ * emitted by the indicator will be picked up and passed via DBus onto
+ * listeners of the application.
 */
 void
 indicate_server_add_indicator (IndicateServer * server, IndicateIndicator * indicator)
@@ -1340,12 +1340,12 @@ indicate_server_add_indicator (IndicateServer * server, IndicateIndicator * indi
 }
 
 /**
-	indicate_server_remove_indicator:
-	@server: The #IndicateServer to remove the #IndicateIndictor from.
-	@indicator: The #IndicateIndicator to remove.
-
-	Removes an indicator @indicator from being watched by the server @server
-	so it's signals are no longer watched and set over DBus.
+ * indicate_server_remove_indicator:
+ * @server: The #IndicateServer to remove the #IndicateIndictor from.
+ * @indicator: The #IndicateIndicator to remove.
+ * 
+ * Removes an indicator @indicator from being watched by the server @server
+ * so it's signals are no longer watched and set over DBus.
 */
 void
 indicate_server_remove_indicator (IndicateServer * server, IndicateIndicator * indicator)
@@ -1387,13 +1387,13 @@ indicate_server_set_dbus_object (const gchar * obj)
 }
 
 /**
-	indicate_server_set_desktop_file:
-	@server: The #IndicateServer to set the type of
-	@path: The new desktop file representing the server
-
-	This is a convience function to set the #IndicateServer:desktop
-	property of the @server object.  The property can also be set
-	via traditional means, but this one is easier to read.
+ * indicate_server_set_desktop_file:
+ * @server: The #IndicateServer to set the type of
+ * @path: The new desktop file representing the server
+ * 
+ * This is a convience function to set the #IndicateServer:desktop
+ * property of the @server object.  The property can also be set
+ * via traditional means, but this one is easier to read.
 */
 void
 indicate_server_set_desktop_file (IndicateServer * server, const gchar * path)
@@ -1406,13 +1406,13 @@ indicate_server_set_desktop_file (IndicateServer * server, const gchar * path)
 }
 
 /**
-	indicate_server_set_type:
-	@server: The #IndicateServer to set the type of
-	@type: The new type of the server
-
-	This is a convience function to set the #IndicateServer:type
-	property of the @server object.  The property can also be set
-	via traditional means, but this one is easier to read.
+ * indicate_server_set_type:
+ * @server: The #IndicateServer to set the type of
+ * @type: The new type of the server
+ * 
+ * This is a convience function to set the #IndicateServer:type
+ * property of the @server object.  The property can also be set
+ * via traditional means, but this one is easier to read.
 */
 void
 indicate_server_set_type (IndicateServer * server, const gchar * type)
@@ -1426,16 +1426,16 @@ indicate_server_set_type (IndicateServer * server, const gchar * type)
 }
 
 /**
-	indicate_server_set_count:
-	@server: The #IndicateServer to set the type of
-	@count: The number of items that the server believes the user
-		would be interested in.
-	
-	A small convience function to set the #IndicateServer:count
-	property on the server.  This should represent a number of messages
-	on a particular server.  This should not be used at the same time
-	as individual indicators to show information to the users.  They
-	sound be used independently.
+ * indicate_server_set_count:
+ * @server: The #IndicateServer to set the type of
+ * @count: The number of items that the server believes the user
+ *         would be interested in.
+ * 
+ * A small convience function to set the #IndicateServer:count
+ * property on the server.  This should represent a number of messages
+ * on a particular server.  This should not be used at the same time
+ * as individual indicators to show information to the users.  They
+ * sound be used independently.
 */
 void
 indicate_server_set_count (IndicateServer * server, guint count)
@@ -1450,15 +1450,15 @@ indicate_server_set_count (IndicateServer * server, guint count)
 static IndicateServer * default_indicate_interface_server = NULL;
 
 /**
-	indicate_server_ref_default:
-
-	This function will return a reference to the default #IndicateServer
-	reference if there is one, or it will create one if one had not
-	previously been created.  It is recommended that all applications
-	use this function to create a #IndicateServer as it ensure that there
-	is only one per application.
-
-	Return value: A reference to the default #IndicateServer instance.
+ * indicate_server_ref_default:
+ * 
+ * This function will return a reference to the default #IndicateServer
+ * reference if there is one, or it will create one if one had not
+ * previously been created.  It is recommended that all applications
+ * use this function to create a #IndicateServer as it ensure that there
+ * is only one per application.
+ * 
+ * Return value: (transfer full): A reference to the default #IndicateServer instance.
 */
 IndicateServer *
 indicate_server_ref_default (void)
@@ -1475,14 +1475,14 @@ indicate_server_ref_default (void)
 }
 
 /**
-	indicate_server_set_default:
-	@server: The #IndicateServer that should be used
-
-	This function is used to set the default #IndicateServer that will
-	be used when creating #IndicateIndicators or for anyone else that
-	calls indicate_server_ref_default().  Typically this is just an
-	instance of #IndicateServer but applications that create a subclass
-	of #IndicateServer should set this as well.
+ * indicate_server_set_default:
+ * @server: The #IndicateServer that should be used
+ * 
+ * This function is used to set the default #IndicateServer that will
+ * be used when creating #IndicateIndicators or for anyone else that
+ * calls indicate_server_ref_default().  Typically this is just an
+ * instance of #IndicateServer but applications that create a subclass
+ * of #IndicateServer should set this as well.
 */
 void
 indicate_server_set_default (IndicateServer * server)
@@ -1928,13 +1928,13 @@ bus_indicator_displayed (IndicateServer * server, GVariant * params, GDBusMethod
 }
 
 /**
-	indicate_server_get_next_id:
-	@server: The #IndicateServer the ID will be on
-
-	Returns the next available unused ID that an indicator
-	can have.
-
-	Return value: A valid indicator ID.
+ * indicate_server_get_next_id:
+ * @server: The #IndicateServer the ID will be on
+ * 
+ * Returns the next available unused ID that an indicator
+ * can have.
+ * 
+ * Return value: A valid indicator ID.
 */
 guint 
 indicate_server_get_next_id (IndicateServer * server)
@@ -2066,15 +2066,15 @@ bus_set_max_indicators (IndicateServer * server, GVariant * params, GDBusMethodI
 }
 
 /**
-	indicate_server_check_interest:
-	@server: The #IndicateServer being checked
-	@interest: Which interest type we're checking for
-
-	This function looks at all the interest that various listeners
-	have specified that they have for this server and returns whether
-	there is a listener that has the interest specified in @interest.
-
-	Return value: %TRUE if a listener as the interest otherwise %FALSE
+ * indicate_server_check_interest:
+ * @server: The #IndicateServer being checked
+ * @interest: Which interest type we're checking for
+ * 
+ * This function looks at all the interest that various listeners
+ * have specified that they have for this server and returns whether
+ * there is a listener that has the interest specified in @interest.
+ * 
+ * Return value: %TRUE if a listener as the interest otherwise %FALSE
 */
 gboolean
 indicate_server_check_interest (IndicateServer * server, IndicateInterests interest)
@@ -2090,13 +2090,13 @@ indicate_server_check_interest (IndicateServer * server, IndicateInterests inter
 }
 
 /**
-	indicate_server_get_max_indicators:
-	@server: The #IndicateServer being checked
-
-	This function looks at everyone listening and determines
-	the max number of indicators that can be shown to anyone.
-
-	Return value: A max number or -1 for unlimited.
+ * indicate_server_get_max_indicators:
+ * @server: The #IndicateServer being checked
+ * 
+ * This function looks at everyone listening and determines
+ * the max number of indicators that can be shown to anyone.
+ * 
+ * Return value: A max number or -1 for unlimited.
 */
 gint
 indicate_server_get_max_indicators (IndicateServer * server)
@@ -2112,20 +2112,20 @@ indicate_server_get_max_indicators (IndicateServer * server)
 }
 
 /**
-	indicate_server_set_menu:
-	@server: The #IndicateServer to use
-	@menu: A #DbusmenuServer object represting the menu
-
-	This function sets the internal menu representation for this
-	indicator.  It makes it so that when clients ask for information
-	on the menus it'll repospond with the address of this menu.
-
-	It is important to note that there is not signal about menus
-	changing.  So if the indicator is already visible there is no
-	way that a listener would know about the change, and thus is
-	likely to have the wrong menu (or no menu).
-
-	Return value: None.
+ * indicate_server_set_menu:
+ * @server: The #IndicateServer to use
+ * @menu: A #DbusmenuServer object represting the menu
+ * 
+ * This function sets the internal menu representation for this
+ * indicator.  It makes it so that when clients ask for information
+ * on the menus it'll repospond with the address of this menu.
+ * 
+ * It is important to note that there is not signal about menus
+ * changing.  So if the indicator is already visible there is no
+ * way that a listener would know about the change, and thus is
+ * likely to have the wrong menu (or no menu).
+ * 
+ * Return value: None.
 */
 void
 indicate_server_set_menu (IndicateServer * server, DbusmenuServer * menu)
